All notable changes will be noted in this file, whenever a tagged
version is made

## [0.2.0] 06/04/2023

Initial release for conda. Several housekeeping improvements, add references to papers.

## [0.1.0] 31/03/2023

Initial release of the aligned-spin model SEOBNRv5HM and the
precessing model SEOBNRv5PHM.
